==> kdebase_3.3.2.orig.tar.gz: kdebase-3.3.2/ksysguard/gui/SensorDisplayLib/SensorLoggerSettings.cc <==
/* This file is part of the KDE project
   Copyright ( C ) 2003 Nadeem Hasan <nhasan@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include "SensorLoggerSettings.h"
#include "SensorLoggerSettingsWidget.h"

#include <klocale.h>

SensorLoggerSettings::SensorLoggerSettings( QWidget *parent, const char *name )
    : KDialogBase( parent, name, true, i18n( "Sensor Logger Settings" ),
      Ok|Apply|Cancel, Ok, true )
{
  m_settingsWidget = new SensorLoggerSettingsWidget( this, "m_settingsWidget" );
  setMainWidget( m_settingsWidget );
}

QString SensorLoggerSettings::title()
{
  return m_settingsWidget->title();
}

QColor SensorLoggerSettings::foregroundColor()
{
  return m_settingsWidget->foregroundColor();
}

QColor SensorLoggerSettings::backgroundColor()
{
  return m_settingsWidget->backgroundColor();
}

QColor SensorLoggerSettings::alarmColor()
{
  return m_settingsWidget->alarmColor();
}

void SensorLoggerSettings::setTitle( const QString &title )
{
  m_settingsWidget->setTitle( title );
}

void SensorLoggerSettings::setBackgroundColor( const QColor &c )
{
  m_settingsWidget->setBackgroundColor( c );
}

void SensorLoggerSettings::setForegroundColor( const QColor &c )
{
  m_settingsWidget->setForegroundColor( c );
}

void SensorLoggerSettings::setAlarmColor( const QColor &c )
{
  m_settingsWidget->setAlarmColor( c );
}

#include "SensorLoggerSettings.moc"

/* vim: et sw=2 ts=2
*/

==> kdebase_3.5.10.orig.tar.gz: kdebase-3.5.10/ksysguard/gui/SensorDisplayLib/SensorLoggerSettings.cc <==
/* This file is part of the KDE project
   Copyright ( C ) 2003 Nadeem Hasan <nhasan@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "SensorLoggerSettings.h"
#include "SensorLoggerSettingsWidget.h"

#include <klocale.h>

SensorLoggerSettings::SensorLoggerSettings( QWidget *parent, const char *name )
    : KDialogBase( parent, name, true, i18n( "Sensor Logger Settings" ),
      Ok|Apply|Cancel, Ok, true )
{
  m_settingsWidget = new SensorLoggerSettingsWidget( this, "m_settingsWidget" );
  setMainWidget( m_settingsWidget );
}

QString SensorLoggerSettings::title()
{
  return m_settingsWidget->title();
}

QColor SensorLoggerSettings::foregroundColor()
{
  return m_settingsWidget->foregroundColor();
}

QColor SensorLoggerSettings::backgroundColor()
{
  return m_settingsWidget->backgroundColor();
}

QColor SensorLoggerSettings::alarmColor()
{
  return m_settingsWidget->alarmColor();
}

void SensorLoggerSettings::setTitle( const QString &title )
{
  m_settingsWidget->setTitle( title );
}

void SensorLoggerSettings::setBackgroundColor( const QColor &c )
{
  m_settingsWidget->setBackgroundColor( c );
}

void SensorLoggerSettings::setForegroundColor( const QColor &c )
{
  m_settingsWidget->setForegroundColor( c );
}

void SensorLoggerSettings::setAlarmColor( const QColor &c )
{
  m_settingsWidget->setAlarmColor( c );
}

#include "SensorLoggerSettings.moc"

/* vim: et sw=2 ts=2
*/
